pub struct Rule(/* private fields */);Expand description
A Lua wrapper for a compiled rusty_rules::Rule that can be evaluated against context data.
It can be efficiently evaluated multiple times against different contexts.
Methods from Deref<Target = Rule<LuaValue>>
Sourcepub fn evaluate(&self, context: &Ctx) -> Result<bool, Box<dyn Error>>
pub fn evaluate(&self, context: &Ctx) -> Result<bool, Box<dyn Error>>
Evaluates a rule synchronously using the provided context.
This method evaluates the rule against the provided context and returns a boolean result indicating whether the rule matched. If the rule contains any async operations, this method will return an error.
Sourcepub async fn evaluate_async(
&self,
context: &Ctx,
) -> Result<bool, Box<dyn Error>>
pub async fn evaluate_async( &self, context: &Ctx, ) -> Result<bool, Box<dyn Error>>
Evaluates a rule asynchronously using the provided context.
This method evaluates the rule against the provided context and returns a boolean result indicating whether the rule matched. It supports rules containing both synchronous and asynchronous operations.